@@ -38,9 +38,3 @@ class prices(Document):
     source_id = ObjectIdField()
     operation = StringField(choices=OPERATIONS.choices())
 
-    def __init__(self, coins, status, source_id, operation, *args, **kwargs):
-        super(prices, self).__init__(*args, **kwargs)
-        self.coins = coins
-        self.status = status
-        self.source_id = source_id
-        self.operation = operation
