@@ -23,4 +23,11 @@ def server_time_out_wrapper(repository, method_to_call, *args):
         raise
     except mongoengine.connection.ConnectionFailure as cf:
         repository.log_error(exception=cf, web_method_name=str(method_to_call), cfg=repository.configuration)
-        raise mongoengine.connection.ConnectionFailure from cf
\ No newline at end of file
+        raise mongoengine.connection.ConnectionFailure from cf
+
+
+def if_empty_string_raise(value):
+    if value is None:
+        raise ValueError(" does not exist ")
+    if value == '':
+        raise ValueError(" does not exist ")
